ChainAccess

Trait ChainAccess 

pub trait ChainAccess {
    // Required method
    fn chain_id(&self) -> u64;
}
Provides access to the chain details of the host environment.

Required Methods

fn chain_id(&self) -> u64

Gets the unique chain identifier of the Arbitrum chain. The semantics are equivalent to that of the EVM’s CHAIN_ID opcode.

Implementors