CryptographyAccess

Trait CryptographyAccess 

pub trait CryptographyAccess {
    // Required method
    fn native_keccak256(&self, input: &[u8]) -> B256;
}
Provides access to native cryptography extensions provided by a Stylus contract host, such as keccak256.

Required Methods

fn native_keccak256(&self, input: &[u8]) -> B256

Efficiently computes the keccak256 hash of the given preimage. The semantics are equivalent to that of the EVM’s SHA3 opcode.

Implementors