pub trait CryptographyAccess {
// Required method
fn native_keccak256(&self, input: &[u8]) -> B256;
}Expand description
Provides access to native cryptography extensions provided by a Stylus contract host, such as keccak256.
pub trait CryptographyAccess {
// Required method
fn native_keccak256(&self, input: &[u8]) -> B256;
}Provides access to native cryptography extensions provided by a Stylus contract host, such as keccak256.